==> bouml_2.2.2.tar.gz: bouml_2.2.2/src/dialog/GenerationSettingsDialog.h <==
// *************************************************************************
//
// Copyright (C) 2004,2005 Bruno PAGES  All rights reserved.
//
// This file is part of the BOUML Uml Toolkit.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// e-mail : bouml@free.fr
// home   : http://bouml.free.fr
//
// *************************************************************************

#ifndef GENERATIONSETTINGSDIALOG_H
#define GENERATIONSETTINGSDIALOG_H

#include <qtabdialog.h>

#include "VisibilityGroup.h"
#include "StringTable.h"
#include "GenerationSettings.h"

class QComboBox;
class QCheckBox;
class QRadioButton;

class LineEdit;
class MultiLineEdit;
class TypesTable;
class StereotypesTable;
class RelationTable;
class IncludeTable;

class GenerationSettingsDialog : public QTabDialog {
  Q_OBJECT
    
  protected:
    // all
    TypesTable * types_table;
  
    // stereotypes
    StereotypesTable * relation_stereotypes_table; 
    StereotypesTable * class_stereotypes_table; 
  
    // C++ specific
    MultiLineEdit * edcpp_h_content;
    MultiLineEdit * edcpp_src_content;
    QComboBox * edcpp_h_extension;
    QComboBox * edcpp_src_extension;
    QCheckBox * cpp_include_with_path_cb;
    LineEdit * cpp_enum_in;
    LineEdit * cpp_enum_out;
    LineEdit * cpp_enum_inout;
    LineEdit * cpp_in;
    LineEdit * cpp_out;
    LineEdit * cpp_inout;
    MultiLineEdit * edcpp_class_decl;
    MultiLineEdit * edcpp_external_class_decl;
    MultiLineEdit * edcpp_struct_decl;
    MultiLineEdit * edcpp_union_decl;
    MultiLineEdit * edcpp_enum_decl;
    MultiLineEdit * edcpp_typedef_decl;
    MultiLineEdit * edcpp_attr_decl;
    MultiLineEdit * edcpp_enum_item_decl;
    MultiLineEdit * edcpp_rel_decl[2][3];
    VisibilityGroup cpp_get_visibility;
    LineEdit * edcpp_get_name;
    QCheckBox * cpp_get_inline_cb;
    QCheckBox * cpp_get_const_cb;
    QCheckBox * cpp_get_value_const_cb;
    VisibilityGroup cpp_set_visibility;
    LineEdit * edcpp_set_name;
    QCheckBox * cpp_set_inline_cb;
    QCheckBox * cpp_set_param_const_cb;
    MultiLineEdit * edcpp_oper_decl;
    MultiLineEdit * edcpp_oper_def;
    QCheckBox * cpp_force_throw_cb;
    IncludeTable * cpp_include_table;
  
    // Java specific
    MultiLineEdit * edjava_src_content;
    QComboBox * edjava_extension;
    MultiLineEdit * edjava_class_decl;
    LineEdit * edjava_external_class_decl;
    MultiLineEdit * edjava_interface_decl;
    MultiLineEdit * edjava_enum_decl;
    MultiLineEdit * edjava_attr_decl;
    MultiLineEdit * edjava_enum_item_decl;
    MultiLineEdit * edjava_enum_item_case;
    MultiLineEdit * edjava_rel_decl[3];
    MultiLineEdit * edjava_oper_def;
    VisibilityGroup java_get_visibility;
    LineEdit * edjava_get_name;
    QCheckBox * java_get_final_cb;
    VisibilityGroup java_set_visibility;
    LineEdit * edjava_set_name;
    QCheckBox * java_set_final_cb;
    QCheckBox * java_set_param_final_cb;
    IncludeTable * java_import_table;
  
    // Idl specific
    MultiLineEdit * edidl_src_content;
    QComboBox * edidl_extension;
    MultiLineEdit * edidl_external_class_decl;
    MultiLineEdit * edidl_interface_decl;
    MultiLineEdit * edidl_valuetype_decl;
    MultiLineEdit * edidl_struct_decl;
    MultiLineEdit * edidl_union_decl;
    MultiLineEdit * edidl_typedef_decl;
    MultiLineEdit * edidl_exception_decl;
    MultiLineEdit * edidl_enum_decl;
    MultiLineEdit * edidl_attr_decl;
    MultiLineEdit * edidl_valuetype_attr_decl;
    MultiLineEdit * edidl_const_decl;
    MultiLineEdit * edidl_union_item_decl;
    MultiLineEdit * edidl_enum_item_decl;
    MultiLineEdit * edidl_rel_decl[3];
    MultiLineEdit * edidl_valuetype_rel_decl[3];
    MultiLineEdit * edidl_union_rel_decl[3];
    MultiLineEdit * edidl_oper_decl;
    LineEdit * edidl_get_name;
    LineEdit * edidl_set_name;
    QCheckBox * idl_set_oneway_cb;
    IncludeTable * idl_include_table;
    
    // directories
    LineEdit * edcpproot;
    LineEdit * edjavaroot;  
    LineEdit * edidlroot;    
    
  public:
    GenerationSettingsDialog(const QPoint & p);
  
  protected:
    void init_types();
    void init_stereotypes();
    void init_cpp1();
    void init_cpp2();
    void init_cpp3();
    void init_cpp4();
    void init_cpp5();
    void init_java1();
    void init_java2();
    void init_java3();
    void init_idl1();
    void init_idl2();
    void init_idl3();
    void init_idl4();
    void init_dirs();
    
  protected slots:
    virtual void accept();
    void cpproot_browse();
    void javaroot_browse();
    void idlroot_browse();
};

class TypesTable : public StringTable {
  public:
    TypesTable(QWidget * parent);
  
    virtual void init_row(int r);

    void update();
    bool check();
};

class StereotypesTable : public StringTable {
  public:
    StereotypesTable(QWidget * parent, int nst, Stereotype * st);
  
    virtual void init_row(int r);
  
    void update(int & nst, Stereotype *& st);
};

class IncludeTable : public MyTable {
  Q_OBJECT

  protected:
    IncludesSpec & spec;
    const char * dflt;
  
    static QString type_copy;		// copy/cut/paste
    static QString include_copy;
  
  public:
    IncludeTable(QWidget * parent, IncludesSpec & spc,
		 const char * title, const char * df);
  
  protected:
    //virtual void activateNextCell();
  
    void insert_row_before(int row);
    void insert_row_after(int row);
    void delete_row(int row);
    void copy_row(int row);
    void cut_row(int row);
    void paste_row(int row);
    void move_row(int from, int to);
    
  public:
    void update();
  
  protected slots:
    void button_pressed(int row, int col, int button, const QPoint & mousePos);
    void value_changed(int row, int col);
};

#endif

==> bouml_2.5.2.tar.gz: bouml_2.5.2/src/dialog/GenerationSettingsDialog.h <==
// *************************************************************************
//
// Copyright (C) 2004,2005 Bruno PAGES  All rights reserved.
//
// This file is part of the BOUML Uml Toolkit.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// e-mail : bouml@free.fr
// home   : http://bouml.free.fr
//
// *************************************************************************

#ifndef GENERATIONSETTINGSDIALOG_H
#define GENERATIONSETTINGSDIALOG_H

#include <qtabdialog.h>

#include "VisibilityGroup.h"
#include "StringTable.h"
#include "GenerationSettings.h"

class QComboBox;
class QCheckBox;
class QRadioButton;

class LineEdit;
class MultiLineEdit;
class TypesTable;
class StereotypesTable;
class RelationTable;
class IncludeTable;

class GenerationSettingsDialog : public QTabDialog {
  Q_OBJECT
    
  protected:
    // all
    TypesTable * types_table;
  
    // stereotypes
    StereotypesTable * relation_stereotypes_table; 
    StereotypesTable * class_stereotypes_table; 
  
    // C++ specific
    MultiLineEdit * edcpp_h_content;
    MultiLineEdit * edcpp_src_content;
    QComboBox * edcpp_h_extension;
    QComboBox * edcpp_src_extension;
    QCheckBox * cpp_include_with_path_cb;
    LineEdit * cpp_enum_in;
    LineEdit * cpp_enum_out;
    LineEdit * cpp_enum_inout;
    LineEdit * cpp_in;
    LineEdit * cpp_out;
    LineEdit * cpp_inout;
    MultiLineEdit * edcpp_class_decl;
    MultiLineEdit * edcpp_external_class_decl;
    MultiLineEdit * edcpp_struct_decl;
    MultiLineEdit * edcpp_union_decl;
    MultiLineEdit * edcpp_enum_decl;
    MultiLineEdit * edcpp_typedef_decl;
    MultiLineEdit * edcpp_attr_decl;
    MultiLineEdit * edcpp_enum_item_decl;
    MultiLineEdit * edcpp_rel_decl[2][3];
    VisibilityGroup cpp_get_visibility;
    LineEdit * edcpp_get_name;
    QCheckBox * cpp_get_inline_cb;
    QCheckBox * cpp_get_const_cb;
    QCheckBox * cpp_get_value_const_cb;
    VisibilityGroup cpp_set_visibility;
    LineEdit * edcpp_set_name;
    QCheckBox * cpp_set_inline_cb;
    QCheckBox * cpp_set_param_const_cb;
    MultiLineEdit * edcpp_oper_decl;
    MultiLineEdit * edcpp_oper_def;
    QCheckBox * cpp_force_throw_cb;
    IncludeTable * cpp_include_table;
  
    // Java specific
    MultiLineEdit * edjava_src_content;
    QComboBox * edjava_extension;
    MultiLineEdit * edjava_class_decl;
    LineEdit * edjava_external_class_decl;
    MultiLineEdit * edjava_interface_decl;
    MultiLineEdit * edjava_enum_decl;
    MultiLineEdit * edjava_attr_decl;
    MultiLineEdit * edjava_enum_item_decl;
    MultiLineEdit * edjava_enum_item_case;
    MultiLineEdit * edjava_rel_decl[3];
    MultiLineEdit * edjava_oper_def;
    VisibilityGroup java_get_visibility;
    LineEdit * edjava_get_name;
    QCheckBox * java_get_final_cb;
    VisibilityGroup java_set_visibility;
    LineEdit * edjava_set_name;
    QCheckBox * java_set_final_cb;
    QCheckBox * java_set_param_final_cb;
    IncludeTable * java_import_table;
  
    // Idl specific
    MultiLineEdit * edidl_src_content;
    QComboBox * edidl_extension;
    MultiLineEdit * edidl_external_class_decl;
    MultiLineEdit * edidl_interface_decl;
    MultiLineEdit * edidl_valuetype_decl;
    MultiLineEdit * edidl_struct_decl;
    MultiLineEdit * edidl_union_decl;
    MultiLineEdit * edidl_typedef_decl;
    MultiLineEdit * edidl_exception_decl;
    MultiLineEdit * edidl_enum_decl;
    MultiLineEdit * edidl_attr_decl;
    MultiLineEdit * edidl_valuetype_attr_decl;
    MultiLineEdit * edidl_const_decl;
    MultiLineEdit * edidl_union_item_decl;
    MultiLineEdit * edidl_enum_item_decl;
    MultiLineEdit * edidl_rel_decl[3];
    MultiLineEdit * edidl_valuetype_rel_decl[3];
    MultiLineEdit * edidl_union_rel_decl[3];
    MultiLineEdit * edidl_oper_decl;
    LineEdit * edidl_get_name;
    LineEdit * edidl_set_name;
    QCheckBox * idl_set_oneway_cb;
    IncludeTable * idl_include_table;
    
    // directories
    LineEdit * edcpproot;
    LineEdit * edjavaroot;  
    LineEdit * edidlroot;    
    
  public:
    GenerationSettingsDialog(const QPoint & p);
  
  protected:
    void init_types();
    void init_stereotypes();
    void init_cpp1();
    void init_cpp2();
    void init_cpp3();
    void init_cpp4();
    void init_cpp5();
    void init_java1();
    void init_java2();
    void init_java3();
    void init_idl1();
    void init_idl2();
    void init_idl3();
    void init_idl4();
    void init_dirs();
    
  protected slots:
    virtual void accept();
    void cpproot_browse();
    void javaroot_browse();
    void idlroot_browse();
};

class TypesTable : public StringTable {
  public:
    TypesTable(QWidget * parent);
  
    virtual void init_row(int r);

    void update();
    bool check();
};

class StereotypesTable : public StringTable {
  public:
    StereotypesTable(QWidget * parent, int nst, Stereotype * st);
  
    virtual void init_row(int r);
  
    void update(int & nst, Stereotype *& st);
};

class IncludeTable : public StringTable {
  protected:
    IncludesSpec & spec;
    const char * dflt;
  
  public:
    IncludeTable(QWidget * parent, IncludesSpec & spc,
		 const char * title, const char * df);
  
  public:
    virtual void init_row(int index);
							   
    void update();
};

#endif
